@@ -28,7 +28,7 @@ dependencies using raw pip. The virtual environment is not created, but one can
 issue `python3 -m venv venv/ && . venv/bin/activate` to create one.
 """
 
-__version__ = "1.2.0"
+__version__ = "1.2.1"
 __author__ = "Fridolin Pokorny <fridex.devel@gmail.com>"
 __title__ = "micropipenv"
 
@@ -48,7 +48,7 @@ from pathlib import Path
 from urllib.parse import urlparse
 
 _LOGGER = logging.getLogger(__title__)
-_SUPPORTED_PIP_STR = ">=9,<=21.3.1"  # Respects requirement in setup.py and latest pip to release date.
+_SUPPORTED_PIP_STR = ">=9,<=22.0.3"  # Respects requirement in setup.py and latest pip to release date.
 
 try:
     from pip import __version__ as pip_version
@@ -185,9 +185,22 @@ def _check_pip_version(raise_on_incompatible=False):  # type: (bool) -> bool
 
 def _import_toml():  # type: () -> Any
     """Import and return toml or pytoml module (in this order)."""
-    for module in "toml", "pytoml":
+    exception_names = {
+        "toml": "TomlDecodeError",
+        "pytoml": "TomlError",
+        "tomli": "TOMLDecodeError",
+    }
+
+    # Only tomli requires TOML files to be opened
+    # in binary mode: https://github.com/hukkin/tomli#parse-a-toml-file
+    open_kwargs = defaultdict(dict)  # type: Dict[str, Dict[str, str]]
+    open_kwargs["tomli"] = {"mode": "rb"}
+
+    for module_name in "toml", "pytoml", "tomli":
         try:
-            return import_module(module)
+            module = import_module(module_name)
+            exception = getattr(module, exception_names[module_name])
+            return module, exception, open_kwargs[module_name]
         except ImportError:
             pass
     else:
@@ -232,14 +245,14 @@ def _read_pipfile_lock():  # type: () -> Any
 
 def _read_pipfile():  # type: () -> Any
     """Find and read Pipfile."""
-    toml = _import_toml()
+    toml, toml_exception, open_kwargs = _import_toml()
 
     pipfile_path = _traverse_up_find_file("Pipfile")
 
     try:
-        with open(pipfile_path) as input_file:
+        with open(pipfile_path, **open_kwargs) as input_file:
             return toml.load(input_file)
-    except toml.TomlDecodeError as exc:
+    except toml_exception as exc:
         raise FileReadError("Failed to parse Pipfile: {}".format(str(exc))) from exc
     except Exception as exc:
         raise FileReadError(str(exc)) from exc
@@ -247,23 +260,23 @@ def _read_pipfile():  # type: () -> Any
 
 def _read_poetry():  # type: () -> Tuple[MutableMapping[str, Any], MutableMapping[str, Any]]
     """Find and read poetry.lock and pyproject.toml."""
-    toml = _import_toml()
+    toml, toml_exception, open_kwargs = _import_toml()
 
     poetry_lock_path = _traverse_up_find_file("poetry.lock")
     pyproject_toml_path = _traverse_up_find_file("pyproject.toml")
 
     try:
-        with open(poetry_lock_path) as input_file:
+        with open(poetry_lock_path, **open_kwargs) as input_file:
             poetry_lock = toml.load(input_file)
-    except toml.TomlDecodeError as exc:
+    except toml_exception as exc:
         raise FileReadError("Failed to parse poetry.lock: {}".format(str(exc))) from exc
     except Exception as exc:
         raise FileReadError(str(exc)) from exc
 
     try:
-        with open(pyproject_toml_path) as input_file:
+        with open(pyproject_toml_path, **open_kwargs) as input_file:
             pyproject_toml = toml.load(input_file)
-    except toml.TomlDecodeError as exc:
+    except toml_exception as exc:
         raise FileReadError("Failed to parse pyproject.toml: {}".format(str(exc))) from exc
     except Exception as exc:
         raise FileReadError(str(exc)) from exc
@@ -397,9 +410,15 @@ def _instantiate_package_finder(pip_session):  # type: (PipSession) -> PackageFi
                 )
 
         link_collector = LinkCollector(session=pip_session, search_scope=search_scope)
+        additional_kwargs = {}
+        # pip 22 deprecates vendored html5lib and uses stdlib html.parser
+        # https://pip.pypa.io/en/latest/news/#id19
+        if Version(pip_version).release >= (22,):
+            additional_kwargs["use_deprecated_html5lib"] = False
         return PackageFinder.create(
             link_collector=link_collector,
             selection_prefs=selection_prefs,
+            **additional_kwargs,  # type: ignore
         )
 
 
